# FEasyTools: Some useful components

### TimeFunc: Data provider as time functions
Calculate an array of data conveniently like a function! A variant of RangeList is also provided to maintain increasing num-pairs.

### ArgChecker: Argument parser with type checking
ArgParser is one of the best argument parser in Python, but it is not good at type checking. To solve this, ArgChecker in this package is developed for better type checking purpose.

### Geometry: Python implemented geometry handler for Points, Segments, and KDTree
In order to deal with large amount of points and segments with labels, this module is included. A mappable KDTree based EdgeFinder is developed, to find segments quickly.

### PQ: Encapsulation of buffered priority queue and heap
Sometimes a priority queue with an extra waiting pool or queue is needing. This module is designed for this.

### SDT Table: A helper for specific type of table
Table helper for the CSV, SDT & SDT.GZ format, and their reader and writer.

### ProbDist: A helper for probability distribution
Provide the encapsulation of several common PDF, make it conveniently to create from XML node.